current_version=$(grep -Po "(?<=version = \")[^\"]*" pyproject.toml)
          # Bump patch version
new_version=$(echo $current_version | awk -F. '{$NF = $NF + 1;} 1' | sed 's/ /./g')
# Update version in pyproject.toml
sed -i "s/version = \"${current_version}\"/version = \"${new_version}\"/" pyproject.toml
echo "new_version=${new_version}" >> "$GITHUB_OUTPUT"
rm -rf dist/*
uv run python -m build &&  uv run twine upload dist/*